import type { CaptchaFactoryInterface } from '../Interface/index.js';
import type { CaptchaFactoryConstructor, TypeBaseConfig } from '../Type/index.js';
export declare class CaptchaFactoryRegistry {
    private static captchaFactories;
    /**
     * Register captcha factory for a provider.
     *
     * @param {string} provider - The unique identifier for the captcha provider factory
     * @param {CaptchaFactoryConstructor} captchaFactoryConstructor - The captcha factory constructor
     * @returns {void}
     */
    static registerCaptchaFactory(provider: string, captchaFactoryConstructor: CaptchaFactoryConstructor<CaptchaFactoryInterface<TypeBaseConfig>, TypeBaseConfig>): void;
    /**
     * Get a captcha factory by provider.
     *
     * @param {string} provider - The unique identifier of the captcha provider factory
     * @returns {CaptchaFactoryConstructor} The captcha factory constructor
     * @throws {Error} If no factory is found for the given provider
     */
    static getCaptchaFactory(provider: string): CaptchaFactoryConstructor<CaptchaFactoryInterface<TypeBaseConfig>, TypeBaseConfig>;
}
