export class CaptchaFactoryRegistry {
    static captchaFactories = {};
    /**
     * Register captcha factory for a provider.
     *
     * @param {string} provider - The unique identifier for the captcha provider factory
     * @param {CaptchaFactoryConstructor} captchaFactoryConstructor - The captcha factory constructor
     * @returns {void}
     */
    static registerCaptchaFactory(provider, captchaFactoryConstructor) {
        this.captchaFactories[provider] = captchaFactoryConstructor;
    }
    /**
     * Get a captcha factory by provider.
     *
     * @param {string} provider - The unique identifier of the captcha provider factory
     * @returns {CaptchaFactoryConstructor} The captcha factory constructor
     * @throws {Error} If no factory is found for the given provider
     */
    static getCaptchaFactory(provider) {
        const factoryClass = this.captchaFactories[provider];
        if (!factoryClass) {
            throw new Error(`No captcha factory found for the provider "${provider}".`);
        }
        return factoryClass;
    }
}
